@@ -3,7 +3,8 @@ use std::ffi::OsString;
 use std::path::{Path, PathBuf};
 
 use bat::assets::HighlightingAssets;
-use clap::{ColorChoice, CommandFactory, FromArgMatches, Parser};
+use clap::{ColorChoice, CommandFactory, FromArgMatches, Parser, ValueEnum, ValueHint};
+use clap_complete::Shell;
 use lazy_static::lazy_static;
 use syntect::highlighting::Theme as SyntaxTheme;
 use syntect::parsing::SyntaxSet;
@@ -250,7 +251,7 @@ pub struct Opt {
     /// intended for other tools that use delta.
     pub color_only: bool,
 
-    #[arg(long = "config", default_value = "", value_name = "PATH")]
+    #[arg(long = "config", default_value = "", value_name = "PATH", value_hint = ValueHint::FilePath)]
     /// Load the config file at PATH instead of ~/.gitconfig.
     pub config: String,
 
@@ -293,6 +294,29 @@ pub struct Opt {
     /// set this in per-repository git config (.git/config)
     pub default_language: Option<String>,
 
+    /// Detect whether or not the terminal is dark or light by querying for its colors.
+    ///
+    /// Ignored if either `--dark` or `--light` is specified.
+    ///
+    /// Querying the terminal for its colors requires "exclusive" access
+    /// since delta reads/writes from the terminal and enables/disables raw mode.
+    /// This causes race conditions with pagers such as less when they are attached to the
+    /// same terminal as delta.
+    ///
+    /// This is usually only an issue when the output is manually piped to a pager.
+    /// For example: `git diff | delta | less`.
+    /// Otherwise, if delta starts the pager itself, then there's no race condition
+    /// since the pager is started *after* the color is detected.
+    ///
+    /// `auto` tries to account for these situations by testing if the output is redirected.
+    ///
+    /// The `--color-only` option is treated as an indicator that delta is used
+    /// as `interactive.diffFilter`. In this case the color is queried from the terminal even
+    /// though the output is redirected.
+    ///
+    #[arg(long = "detect-dark-light", value_enum, default_value_t = DetectDarkLight::default())]
+    pub detect_dark_light: DetectDarkLight,
+
     #[arg(long = "diff-highlight")]
     /// Emulate diff-highlight.
     ///
@@ -390,6 +414,10 @@ pub struct Opt {
     /// Sed-style command transforming file paths for display.
     pub file_regex_replacement: Option<String>,
 
+    #[arg(long = "generate-completion")]
+    /// Print completion file for the given shell.
+    pub generate_completion: Option<Shell>,
+
     #[arg(long = "grep-context-line-style", value_name = "STYLE")]
     /// Style string for non-matching lines of grep output.
     ///
@@ -409,7 +437,7 @@ pub struct Opt {
     #[arg(long = "grep-header-decoration-style", value_name = "STYLE")]
     /// Style string for the header decoration in grep output.
     ///
-    /// Default is "none" when grep-ouput-type-is "ripgrep", otherwise defaults
+    /// Default is "none" when grep-output-type-is "ripgrep", otherwise defaults
     /// to value of header-decoration-style. See hunk-header-decoration-style.
     pub grep_header_decoration_style: Option<String>,
 
@@ -419,12 +447,6 @@ pub struct Opt {
     /// See hunk_header_file_style.
     pub grep_header_file_style: Option<String>,
 
-    #[arg(long = "grep-header-style", value_name = "STYLE")]
-    /// Style string for the header in grep output.
-    ///
-    /// See hunk-header-style.
-    pub grep_header_style: Option<String>,
-
     #[arg(
         long = "grep-line-number-style",
         default_value = "green",
@@ -435,7 +457,7 @@ pub struct Opt {
     /// See STYLES section.
     pub grep_line_number_style: String,
 
-    #[arg(long = "grep-output-type", value_name = "OUTPUT_TYPE")]
+    #[arg(long = "grep-output-type", value_name = "OUTPUT_TYPE", value_parser = ["ripgrep", "classic"])]
     /// Grep output format. Possible values:
     /// "ripgrep" - file name printed once, followed by matching lines within that file, each preceded by a line number.
     /// "classic" - file name:line number, followed by matching line.
@@ -569,7 +591,8 @@ pub struct Opt {
     #[arg(
         long = "inspect-raw-lines",
         default_value = "true",
-        value_name = "true|false"
+        value_name = "true|false",
+        value_parser = ["true", "false"],
     )]
     /// Kill-switch for --color-moved support.
     ///
@@ -601,7 +624,7 @@ pub struct Opt {
     /// affect delta's performance when entire files are added/removed.
     pub line_buffer_size: usize,
 
-    #[arg(long = "line-fill-method", value_name = "STRING")]
+    #[arg(long = "line-fill-method", value_name = "STRING", value_parser = ["ansi", "spaces"])]
     /// Line-fill method in side-by-side mode.
     ///
     /// How to extend the background color to the end of the line in side-by-side mode. Can be ansi
@@ -844,15 +867,16 @@ pub struct Opt {
     #[arg(long = "pager", value_name = "CMD")]
     /// Which pager to use.
     ///
-    /// The default pager is `less`. You can also change pager by setting the environment variables
-    /// DELTA_PAGER, BAT_PAGER, or PAGER (and that is their order of priority). This option
-    /// overrides all environment variables above.
+    /// The default pager is `less`. You can also change pager by setting the
+    /// environment variable DELTA_PAGER, or PAGER. This option overrides these
+    /// environment variables.
     pub pager: Option<String>,
 
     #[arg(
         long = "paging",
         default_value = "auto",
-        value_name = "auto|always|never"
+        value_name = "auto|always|never",
+        value_parser = ["auto", "always", "never"],
     )]
     /// Whether to use a pager when displaying output.
     ///
@@ -981,7 +1005,8 @@ pub struct Opt {
     #[arg(
         long = "true-color",
         default_value = "auto",
-        value_name = "auto|always|never"
+        value_name = "auto|always|never",
+        value_parser = ["auto", "always", "never"],
     )]
     /// Whether to emit 24-bit ("true color") RGB color codes.
     ///
@@ -1072,7 +1097,7 @@ pub struct Opt {
     /// See STYLES section.
     pub zero_style: String,
 
-    #[arg(long = "24-bit-color", value_name = "auto|always|never")]
+    #[arg(long = "24-bit-color", value_name = "auto|always|never", value_parser = ["auto", "always", "never"])]
     /// Deprecated: use --true-color.
     pub _24_bit_color: Option<String>,
 
@@ -1122,6 +1147,17 @@ pub enum InspectRawLines {
     False,
 }
 
+#[derive(Clone, Copy, Debug, Default, PartialEq, Eq, ValueEnum)]
+pub enum DetectDarkLight {
+    /// Only query the terminal for its colors if the output is not redirected.
+    #[default]
+    Auto,
+    /// Always query the terminal for its colors.
+    Always,
+    /// Never query the terminal for its colors.
+    Never,
+}
+
 impl Opt {
     pub fn from_args_and_git_config(
         env: DeltaEnv,
@@ -1200,6 +1236,7 @@ impl Opt {
 // pseudo-flag commands such as --list-languages
 lazy_static! {
     static ref IGNORED_OPTION_NAMES: HashSet<&'static str> = vec![
+        "generate-completion",
         "list-languages",
         "list-syntax-themes",
         "show-config",
