@@ -1,8 +1,3 @@
-extern crate bitflags;
-
-#[macro_use]
-extern crate error_chain;
-
 mod align;
 mod ansi;
 mod cli;
@@ -29,7 +24,7 @@ mod subcommands;
 
 mod tests;
 
-use std::io::{self, ErrorKind};
+use std::io::{self, ErrorKind, IsTerminal};
 use std::process;
 
 use bytelines::ByteLinesReader;
@@ -44,7 +39,7 @@ where
 {
     #[cfg(not(test))]
     {
-        eprintln!("{}", errmsg);
+        eprintln!("{errmsg}");
         // As in Config::error_exit_code: use 2 for error
         // because diff uses 0 and 1 for non-error.
         process::exit(2);
@@ -54,13 +49,7 @@ where
 }
 
 pub mod errors {
-    error_chain! {
-        foreign_links {
-            Io(::std::io::Error);
-            SyntectError(::syntect::LoadingError);
-            ParseIntError(::std::num::ParseIntError);
-        }
-    }
+    pub use anyhow::{anyhow, Context, Error, Result};
 }
 
 #[cfg(not(tarpaulin_include))]
@@ -74,7 +63,7 @@ fn main() -> std::io::Result<()> {
     // Ignore ctrl-c (SIGINT) to avoid leaving an orphaned pager process.
     // See https://github.com/dandavison/delta/issues/681
     ctrlc::set_handler(|| {})
-        .unwrap_or_else(|err| eprintln!("Failed to set ctrl-c handler: {}", err));
+        .unwrap_or_else(|err| eprintln!("Failed to set ctrl-c handler: {err}"));
     let exit_code = run_app()?;
     // when you call process::exit, no destructors are called, so we want to do it only once, here
     process::exit(exit_code);
@@ -93,7 +82,11 @@ fn run_app() -> std::io::Result<i32> {
         assets,
     );
 
-    let subcommand_result = if opt.list_languages {
+    let subcommand_result = if let Some(shell) = opt.generate_completion {
+        Some(subcommands::generate_completion::generate_completion_file(
+            shell,
+        ))
+    } else if opt.list_languages {
         Some(list_languages())
     } else if opt.list_syntax_themes {
         Some(subcommands::list_syntax_themes::list_syntax_themes())
@@ -116,7 +109,7 @@ fn run_app() -> std::io::Result<i32> {
         if let Err(error) = result {
             match error.kind() {
                 ErrorKind::BrokenPipe => {}
-                _ => fatal(format!("{}", error)),
+                _ => fatal(format!("{error}")),
             }
         }
         return Ok(0);
@@ -141,11 +134,11 @@ fn run_app() -> std::io::Result<i32> {
         return Ok(exit_code);
     }
 
-    if atty::is(atty::Stream::Stdin) {
+    if io::stdin().is_terminal() {
         eprintln!(
             "\
     The main way to use delta is to configure it as the pager for git: \
-    see https://github.com/dandavison/delta#configuration. \
+    see https://github.com/dandavison/delta#get-started. \
     You can also use delta to diff two files: `delta file_A file_B`."
         );
         return Ok(config.error_exit_code);
@@ -154,7 +147,7 @@ fn run_app() -> std::io::Result<i32> {
     if let Err(error) = delta(io::stdin().lock().byte_lines(), &mut writer, &config) {
         match error.kind() {
             ErrorKind::BrokenPipe => return Ok(0),
-            _ => eprintln!("{}", error),
+            _ => eprintln!("{error}"),
         }
     };
     Ok(0)
