@@ -1,5 +1,3 @@
-use lazy_static::lazy_static;
-use regex::Regex;
 use std::collections::HashMap;
 
 use crate::cli;
@@ -11,7 +9,7 @@ use ProvenancedOptionValue::*;
 // Look up a value of type `T` associated with `option name`. The search rules are:
 //
 // 1. If there is a value associated with `option_name` in the main [delta] git config
-//    section, then stop searching and return that value.
+//    section, then stop searching and return that value (steps 2 and 3 are not executed at all).
 //
 // 2. For each feature in the ordered list of enabled features:
 //
@@ -40,23 +38,21 @@ where
     T::get_option_value(option_name, builtin_features, opt, git_config)
 }
 
-lazy_static! {
-    static ref GIT_CONFIG_THEME_REGEX: Regex = Regex::new(r"^delta\.(.+)\.(light|dark)$").unwrap();
-}
+static GIT_CONFIG_THEME_REGEX: &str = r#"^delta\.(.+)\.(light|dark)$"#;
 
 pub fn get_themes(git_config: Option<git_config::GitConfig>) -> Vec<String> {
     let mut themes: Vec<String> = Vec::new();
-    for e in &git_config.unwrap().config.entries(None).unwrap() {
-        let entry = e.unwrap();
-        let entry_name = entry.name().unwrap();
-        let caps = GIT_CONFIG_THEME_REGEX.captures(entry_name);
-        if let Some(caps) = caps {
-            let name = caps.get(1).map_or("", |m| m.as_str()).to_string();
-            if !themes.contains(&name) {
-                themes.push(name)
+    let git_config = git_config.unwrap();
+    git_config.for_each(GIT_CONFIG_THEME_REGEX, |name, _| {
+        if let Some(name) = name.strip_prefix("delta.") {
+            if let Some((name, _)) = name.rsplit_once('.') {
+                let name = name.to_owned();
+                if !themes.contains(&name) {
+                    themes.push(name);
+                }
             }
         }
-    }
+    });
     themes.sort_by_key(|a| a.to_lowercase());
     themes
 }
@@ -75,7 +71,7 @@ pub trait GetOptionValue {
         Self: Into<OptionValue>,
     {
         if let Some(git_config) = git_config {
-            if let Some(value) = git_config.get::<Self>(&format!("delta.{}", option_name)) {
+            if let Some(value) = git_config.get::<Self>(&format!("delta.{option_name}")) {
                 return Some(value);
             }
         }
@@ -114,9 +110,7 @@ pub trait GetOptionValue {
         Self: Into<OptionValue>,
     {
         if let Some(git_config) = git_config {
-            if let Some(value) =
-                git_config.get::<Self>(&format!("delta.{}.{}", feature, option_name))
-            {
+            if let Some(value) = git_config.get::<Self>(&format!("delta.{feature}.{option_name}")) {
                 return Some(GitConfigValue(value.into()));
             }
         }
@@ -231,8 +225,8 @@ pub mod tests {
             git_config_contents,
             git_config_path,
             "'delta.side-by-side=false'".into(),
-            &|opt: Opt| assert_eq!(opt.side_by_side, true),
-            &|opt: Opt| assert_eq!(opt.side_by_side, false),
+            &|opt: Opt| assert!(opt.side_by_side),
+            &|opt: Opt| assert!(!opt.side_by_side),
         );
     }
 
@@ -282,7 +276,7 @@ pub mod tests {
             Some(git_config_path),
         );
         assert_eq!(opt.features.unwrap(), "feature-from-gitconfig");
-        assert_eq!(opt.side_by_side, false);
+        assert!(!opt.side_by_side);
 
         let opt = integration_test_utils::make_options_from_args_and_git_config_with_custom_env(
             DeltaEnv {
@@ -295,7 +289,7 @@ pub mod tests {
         );
         // `line-numbers` is a builtin feature induced by side-by-side
         assert_eq!(opt.features.unwrap(), "line-numbers side-by-side");
-        assert_eq!(opt.side_by_side, true);
+        assert!(opt.side_by_side);
 
         let opt = integration_test_utils::make_options_from_args_and_git_config_with_custom_env(
             DeltaEnv {
@@ -310,7 +304,7 @@ pub mod tests {
             opt.features.unwrap(),
             "feature-from-gitconfig line-numbers side-by-side"
         );
-        assert_eq!(opt.side_by_side, true);
+        assert!(opt.side_by_side);
 
         remove_file(git_config_path).unwrap();
     }
